@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 ''' Python API for YouTube
     Copyright (C)  2013 nagev
 
@@ -14,7 +16,7 @@
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.  '''
 
-__version__ = "0.3.22"
+__version__ = "0.3.23"
 __author__ = "nagev"
 __license__ = "GPLv3"
 
@@ -253,6 +255,7 @@ class Pafy():
     def __repr__(self):
         keys = "Title Author ID Duration Rating Views Thumbnail Keywords"
         keys = keys.split(" ")
+        self.keywords = self.keywords or ""
         keywords = ", ".join(self.keywords)
         length = time.strftime('%H:%M:%S', time.gmtime(self.length))
         info = dict(Title=self.title,
